summaryrefslogtreecommitdiff
path: root/Kernel/FileSystem/BlockBasedFileSystem.cpp
diff options
context:
space:
mode:
authorAndreas Kling <kling@serenityos.org>2021-07-11 00:33:27 +0200
committerAndreas Kling <kling@serenityos.org>2021-07-11 00:33:27 +0200
commit502bbacea0921038d3c1d5fb713a12f602b7cac7 (patch)
treeb4d4d8835b8a7f9ea396d407e7aa3b0dc45b640f /Kernel/FileSystem/BlockBasedFileSystem.cpp
parent07c4c892970275090ed60b4f7962b87d8fb93b1a (diff)
downloadserenity-502bbacea0921038d3c1d5fb713a12f602b7cac7.zip
Kernel: Rename FileBackedFS => FileBackedFileSystem
Diffstat (limited to 'Kernel/FileSystem/BlockBasedFileSystem.cpp')
-rw-r--r--Kernel/FileSystem/BlockBasedFileSystem.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Kernel/FileSystem/BlockBasedFileSystem.cpp b/Kernel/FileSystem/BlockBasedFileSystem.cpp
index f0619cbc9d..7a4af3db07 100644
--- a/Kernel/FileSystem/BlockBasedFileSystem.cpp
+++ b/Kernel/FileSystem/BlockBasedFileSystem.cpp
@@ -64,8 +64,8 @@ public:
if (m_clean_list.is_empty()) {
// Not a single clean entry! Flush writes and try again.
// NOTE: We want to make sure we only call FileBackedFS flush here,
// not some FileBackedFS subclass flush!
m_fs.flush_writes_impl();
return get(block_index);
}
@@ -105,7 +105,7 @@ private:
};
BlockBasedFS::BlockBasedFS(FileDescription& file_description)
- : FileBackedFS(file_description)
+ : FileBackedFileSystem(file_description)
{
VERIFY(file_description.file().is_seekable());
}
@@ -64,8 +64,8 @@ public:
if (m_clean_list.is_empty()) {
// Not a single clean entry! Flush writes and try again.
- // NOTE: We want to make sure we only call FileBackedFS flush here,
- // not some FileBackedFS subclass flush!
+ // NOTE: We want to make sure we only call FileBackedFileSystem flush here,
+ // not some FileBackedFileSystem subclass flush!
m_fs.flush_writes_impl();
return get(block_index);